@@ -18,11 +18,12 @@ from .base import Relation
 from .conf import DatabaseConnection
 from .conf import load_config
 from .conf import DATABASES
+from .enginemanager import EngineManager
 from .repository import RelationalDatabaseRepository
 
 
-ENGINES = {}
-ASYNC_ENGINES = {}
+ENGINES = EngineManager()
+ASYNC_ENGINES = EngineManager()
 
 
 def awaitservices(max_retries=60, interval=1, databases=None):
@@ -44,7 +45,7 @@ def awaitservices(max_retries=60, interval=1, databases=None):
         ready = []
         attempts = 0
         while True:
-            if set(ready) == set(dict.keys(databases)):
+            if set(ready) == set(databases.keys()):
                 break
             if attempts >= max_retries:
                 raise RuntimeError(
@@ -52,7 +53,7 @@ def awaitservices(max_retries=60, interval=1, databases=None):
             futures = executor.map(
                 DatabaseConnection.wait,
                 [databases[name]
-                    for name in dict.keys(databases)
+                    for name in databases.keys()
                     if name not in ready
                 ]
             )
@@ -116,15 +117,8 @@ def declarative_base(cls=None, class_factory=None, settings=None, apps=None):
 
 def destroy_engines(loop=None):
     """Destroys all known engines."""
-    for name in list(dict.keys(ENGINES)):
-        engine = ENGINES.pop(name)
-        engine.dispose()
-
-    for name in list(dict.keys(ASYNC_ENGINES)):
-        engine = ASYNC_ENGINES.pop(name)
-        asyncio.run(engine.dispose())\
-            if loop is None\
-            else loop.run_until_complete(engine.dispose())
+    ENGINES.destroy()
+    ASYNC_ENGINES.destroy(loop=loop)
 
 
 def create_engine(name='self', *args, **kwargs):
